import { ActionTree } from "vuex";
import { Actions, ActionType, MutationType, State } from "./_type";
import { RootState } from "@/store";
import asyncRoutes from "@/router/async";
import { filterRoutesByRoles } from "@/helper/permission";

import { doLogin, getOfficialSimpleAccount } from "@/api";

type userData = {
  account: string;
  passwd: string;
};

const actions: ActionTree<State, RootState> & Actions = {
  [ActionType.generatorRoutes]({ commit }, roles) {
    return new Promise(async (resolve) => {
      let resultRoutes = filterRoutesByRoles(asyncRoutes, roles) || [];
      await commit(MutationType.setRoutes, resultRoutes);
      resolve(resultRoutes);
    });
  },
  [ActionType.getUserRoles]({ commit }) {
    return new Promise(async (resolve) => {
      const roles = ["admin"];
      await commit(MutationType.setRoles, roles);
      resolve(roles);
    });
  },
  async [ActionType.doLogin]({ commit }, user: userData) {
    try {
      const { data } = await doLogin<userData>(user);
      commit(MutationType.setUser, data);
    } catch (e) {
      console.log("error", e);
    }
  },
  async [ActionType.doSaveOfficial]({ commit }) {
    try {
      const { data } = await getOfficialSimpleAccount();
      const storeOfficials: SelectOptions<number> = data.map((item) => {
        return {
          label: item.name,
          value: item.id,
        };
      });
      commit(MutationType.setOfficial, storeOfficials);
    } catch (e) {
      console.log("error", e);
    }
  },
};

export default actions;
